"""Module with vectors in euclidean space"""

class Vector2D:
    """2D vector in euclidean space"""

    dimension = 2

    def __init__(self, x=0, y=0):
        self.x = x
        self.y = y

    @property
    def euclidean_norm(self):
        """Compute the euclidean norm of this vector"""
        return (self.x ** 2 + self.y ** 2) ** 0.5

    def __str__(self):
        return f"Vector2D(x={self.x}, y={self.y})"

    def __add__(self, vec2):
        return Vector2D(self.x + vec2.x, self.y + vec2.y)

    def __mul__(self, scalar):
        return Vector2D(self.x * scalar, self.y * scalar)

    def __rmul__(self, scalar):
        return self * scalar

    def __eq__(self, other):
        return self.x == other.x and self.y == other.y

    @staticmethod
    def zero_vector():
        """Create a zero vector instance"""
        return Vector2D(0, 0)


class YVector2D(Vector2D):
   """Vector with only y coordinate (x coordinate is always 0)"""

    def __init__(self, y):
        super().__init__(0, y)


class NonPositiveValueError(ValueError):
    """Given value is not positive"""

    def __init__(self, val):
        super().__init__(f"Value must be positive (given {val})")


class PositiveYVector2D(YVector2D):
    """Vector with only y coordinate which must be positive"""

    def __init__(self, y):
        if y <= 0:
            raise NonPositiveValueError(y)
        super().__init__(y)


if __name__ == "__main__":
    try:
        vec_a = PositiveYVector2D(-10)
    except NonPositiveValueError as exc:
        print(exc)

